@@ -22,6 +22,7 @@ if not os.environ.get('VOICEMODE_DEBUG', '').lower() in ('true', '1', 'yes'):
     # Also suppress INFO logging for CLI commands (but not for MCP server)
     import logging
     logging.getLogger("voice-mode").setLevel(logging.WARNING)
+    logging.getLogger("httpx").setLevel(logging.WARNING)
 
 
 # Service management CLI - runs MCP server by default, subcommands override
@@ -1358,12 +1359,27 @@ def cli():
 
 # Import subcommand groups
 from voice_mode.cli_commands import exchanges as exchanges_cmd
+from voice_mode.cli_commands import transcribe as transcribe_cmd
+from voice_mode.cli_commands import pronounce_commands
+from voice_mode.cli_commands import claude
+from voice_mode.cli_commands import hook as hook_cmd
 
 # Add subcommands to legacy CLI
 cli.add_command(exchanges_cmd.exchanges)
+cli.add_command(transcribe_cmd.transcribe)
+cli.add_command(pronounce_commands.pronounce_group)
+cli.add_command(claude.claude_group)
 
 # Add exchanges to main CLI
 voice_mode_main_cli.add_command(exchanges_cmd.exchanges)
+voice_mode_main_cli.add_command(pronounce_commands.pronounce_group)
+voice_mode_main_cli.add_command(claude.claude_group)
+
+# Add transcribe to main CLI
+voice_mode_main_cli.add_command(transcribe_cmd.transcribe)
+
+# Add hook command to main CLI
+voice_mode_main_cli.add_command(hook_cmd.hook)
 
 
 # Converse command - direct voice conversation from CLI
@@ -1742,6 +1758,69 @@ def update(force):
                 click.echo("Try running: pip install --upgrade voice-mode")
 
 
+# Sound Fonts command
+@voice_mode_main_cli.command("play-sound")
+@click.help_option('-h', '--help')
+@click.option('-t', '--tool', help='Tool name for direct command-line usage')
+@click.option('-a', '--action', default='start', type=click.Choice(['start', 'end']), help='Action type')
+@click.option('-s', '--subagent', help='Subagent type (for Task tool)')
+def play_sound(tool, action, subagent):
+    """Play sound based on tool events (primarily for Claude Code hooks).
+    
+    This command is designed to be called by Claude Code hooks to play sounds
+    when tools are used. It reads hook data from stdin by default, or can be
+    used directly with command-line options.
+    
+    Examples:
+        echo '{"tool_name":"Task","tool_input":{"subagent_type":"mama-bear"}}' | voicemode play-sound
+        voicemode play-sound --tool Task --action start --subagent mama-bear
+    """
+    import sys
+    from .tools.sound_fonts.player import AudioPlayer
+    from .tools.sound_fonts.hook_handler import (
+        read_hook_data_from_stdin,
+        parse_claude_code_hook
+    )
+    
+    # Try to read hook data from stdin first
+    hook_data = None
+    if not sys.stdin.isatty():
+        hook_data = read_hook_data_from_stdin()
+    
+    if hook_data:
+        # Parse Claude Code hook format
+        parsed_data = parse_claude_code_hook(hook_data)
+        if not parsed_data:
+            sys.exit(1)
+            
+        tool_name = parsed_data["tool_name"]
+        action_type = parsed_data["action"]
+        subagent_type = parsed_data["subagent_type"]
+        metadata = parsed_data["metadata"]
+    else:
+        # Use command-line arguments
+        if not tool:
+            click.echo("Error: --tool is required when not reading from stdin", err=True)
+            sys.exit(1)
+            
+        tool_name = tool
+        action_type = action
+        subagent_type = subagent
+        metadata = {}
+    
+    # Play the sound
+    player = AudioPlayer()
+    success = player.play_sound_for_event(
+        tool_name=tool_name,
+        action=action_type,
+        subagent_type=subagent_type,
+        metadata=metadata
+    )
+    
+    # Silent exit for hooks - don't clutter Claude Code output
+    sys.exit(0 if success else 1)
+
+
 # Completions command
 @voice_mode_main_cli.command()
 @click.help_option('-h', '--help')
