@@ -73,14 +73,12 @@ def get_service_config_vars(service_name: str) -> Dict[str, Any]:
                 # Try GPU scripts first
                 possible_scripts = [
                     Path(kokoro_dir) / "start-gpu.sh",
-                    Path(kokoro_dir) / "start.sh",  # fallback
                     Path(kokoro_dir) / "start-cpu.sh"  # last resort
                 ]
             else:
                 # No GPU, prefer CPU script
                 possible_scripts = [
                     Path(kokoro_dir) / "start-cpu.sh",
-                    Path(kokoro_dir) / "start.sh",  # fallback
                     Path(kokoro_dir) / "start-gpu.sh"  # might work with CPU fallback
                 ]
             
@@ -409,14 +407,12 @@ async def start_service(service_name: str) -> str:
                 # Try GPU scripts first
                 possible_scripts = [
                     Path(kokoro_dir) / "start-gpu.sh",
-                    Path(kokoro_dir) / "start.sh",  # fallback
                     Path(kokoro_dir) / "start-cpu.sh"  # last resort
                 ]
             else:
                 # No GPU, prefer CPU script
                 possible_scripts = [
                     Path(kokoro_dir) / "start-cpu.sh",
-                    Path(kokoro_dir) / "start.sh",  # fallback
                     Path(kokoro_dir) / "start-gpu.sh"  # might work with CPU fallback
                 ]
             
@@ -582,12 +578,18 @@ async def enable_service(service_name: str) -> str:
                 if not model_file:
                     return "❌ No Whisper model found. Please run download_model first."
                 
+                # Find the start script
+                # whisper_bin is at ~/.voicemode/services/whisper/build/bin/whisper-server
+                # start script is at ~/.voicemode/services/whisper/bin/start-whisper-server.sh
+                install_dir = Path(whisper_bin).parent.parent.parent  # Go up from build/bin/whisper-server to whisper dir
+                start_script_path = install_dir / "bin" / "start-whisper-server.sh"
+                if not start_script_path.exists():
+                    return f"❌ Start script not found: {start_script_path}"
+                
                 content = template.format(
-                    WHISPER_BIN=whisper_bin,
-                    WHISPER_PORT=WHISPER_PORT,
-                    MODEL_FILE=model_file,
-                    LOG_DIR=logs_dir,
-                    WORKING_DIR=Path(whisper_bin).parent
+                    START_SCRIPT_PATH=str(start_script_path),
+                    LOG_DIR=str(logs_dir),
+                    INSTALL_DIR=str(install_dir)
                 )
             elif service_name == "kokoro":
                 kokoro_dir = find_kokoro_fastapi()
@@ -682,14 +684,12 @@ async def enable_service(service_name: str) -> str:
                     # Try GPU scripts first
                     possible_scripts = [
                         Path(kokoro_dir) / "start-gpu.sh",
-                        Path(kokoro_dir) / "start.sh",  # fallback
                         Path(kokoro_dir) / "start-cpu.sh"  # last resort
                     ]
                 else:
                     # No GPU, prefer CPU script
                     possible_scripts = [
                         Path(kokoro_dir) / "start-cpu.sh",
-                        Path(kokoro_dir) / "start.sh",  # fallback
                         Path(kokoro_dir) / "start-gpu.sh"  # might work with CPU fallback
                     ]
                 
@@ -1094,4 +1094,4 @@ async def uninstall_service(service_name: str) -> Dict[str, Any]:
                 
     except Exception as e:
         logger.error(f"Error uninstalling service {service_name}: {e}")
-        return {"success": False, "error": str(e)}
\ No newline at end of file
+        return {"success": False, "error": str(e)}
