@@ -22,6 +22,152 @@ from voice_mode.utils.migration_helpers import auto_migrate_if_needed
 logger = logging.getLogger("voice-mode")
 
 
+async def update_kokoro_service_files(
+    install_dir: str,
+    voicemode_dir: str,
+    port: int,
+    start_script_path: str,
+    auto_enable: Optional[bool] = None
+) -> Dict[str, Any]:
+    """Update service files (plist/systemd) for kokoro service.
+    
+    This function updates the service files without reinstalling kokoro itself.
+    It ensures paths are properly expanded and templates are up to date.
+    
+    Returns:
+        Dict with success status and details about what was updated
+    """
+    system = platform.system()
+    result = {"success": False, "updated": False}
+    
+    # Create log directory
+    log_dir = os.path.join(voicemode_dir, 'logs', 'kokoro')
+    os.makedirs(log_dir, exist_ok=True)
+    
+    if system == "Darwin":
+        logger.info("Updating launchagent for kokoro...")
+        launchagents_dir = os.path.expanduser("~/Library/LaunchAgents")
+        os.makedirs(launchagents_dir, exist_ok=True)
+        
+        plist_name = "com.voicemode.kokoro.plist"
+        plist_path = os.path.join(launchagents_dir, plist_name)
+        
+        plist_content = f"""<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+    <key>Label</key>
+    <string>com.voicemode.kokoro</string>
+    <key>ProgramArguments</key>
+    <array>
+        <string>{start_script_path}</string>
+    </array>
+    <key>WorkingDirectory</key>
+    <string>{install_dir}</string>
+    <key>RunAtLoad</key>
+    <true/>
+    <key>KeepAlive</key>
+    <true/>
+    <key>StandardOutPath</key>
+    <string>{os.path.join(voicemode_dir, 'logs', 'kokoro', 'kokoro.log')}</string>
+    <key>StandardErrorPath</key>
+    <string>{os.path.join(voicemode_dir, 'logs', 'kokoro', 'kokoro.error.log')}</string>
+    <key>EnvironmentVariables</key>
+    <dict>
+        <key>PATH</key>
+        <string>{os.path.expanduser("~/.local/bin")}:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin:/opt/homebrew/bin</string>
+    </dict>
+</dict>
+</plist>"""
+        
+        # Unload if already loaded (ignore errors)
+        try:
+            subprocess.run(["launchctl", "unload", plist_path], capture_output=True)
+        except:
+            pass
+        
+        # Write updated plist
+        with open(plist_path, 'w') as f:
+            f.write(plist_content)
+        
+        result["success"] = True
+        result["updated"] = True
+        result["plist_path"] = plist_path
+        
+        # Handle auto_enable if specified
+        if auto_enable is None:
+            auto_enable = SERVICE_AUTO_ENABLE
+        
+        if auto_enable:
+            logger.info("Auto-enabling kokoro service...")
+            from voice_mode.tools.service import enable_service
+            enable_result = await enable_service("kokoro")
+            if "✅" in enable_result:
+                result["enabled"] = True
+            else:
+                logger.warning(f"Auto-enable failed: {enable_result}")
+                result["enabled"] = False
+    
+    elif system == "Linux":
+        logger.info("Updating systemd user service for kokoro...")
+        systemd_user_dir = os.path.expanduser("~/.config/systemd/user")
+        os.makedirs(systemd_user_dir, exist_ok=True)
+        
+        service_name = "voicemode-kokoro.service"
+        service_path = os.path.join(systemd_user_dir, service_name)
+        
+        service_content = f"""[Unit]
+Description=VoiceMode Kokoro TTS Service
+After=network.target
+[Service]
+Type=simple
+ExecStart={start_script_path}
+Restart=on-failure
+RestartSec=10
+WorkingDirectory={install_dir}
+StandardOutput=append:{os.path.join(voicemode_dir, 'logs', 'kokoro', 'kokoro.log')}
+StandardError=append:{os.path.join(voicemode_dir, 'logs', 'kokoro', 'kokoro.error.log')}
+Environment="PATH=/usr/local/bin:/usr/bin:/bin:/home/m/.local/bin"
+[Install]
+WantedBy=default.target
+"""
+        
+        with open(service_path, 'w') as f:
+            f.write(service_content)
+        
+        # Reload systemd
+        try:
+            subprocess.run(["systemctl", "--user", "daemon-reload"], check=True)
+            result["success"] = True
+            result["updated"] = True
+            result["service_path"] = service_path
+        except subprocess.CalledProcessError as e:
+            logger.warning(f"Failed to reload systemd: {e}")
+            result["success"] = True  # Still consider it success if file was written
+            result["updated"] = True
+            result["service_path"] = service_path
+        
+        # Handle auto_enable if specified
+        if auto_enable is None:
+            auto_enable = SERVICE_AUTO_ENABLE
+        
+        if auto_enable:
+            logger.info("Auto-enabling kokoro service...")
+            from voice_mode.tools.service import enable_service
+            enable_result = await enable_service("kokoro")
+            if "✅" in enable_result:
+                result["enabled"] = True
+            else:
+                logger.warning(f"Auto-enable failed: {enable_result}")
+                result["enabled"] = False
+    
+    else:
+        result["success"] = False
+        result["error"] = f"Unsupported platform: {system}"
+    
+    return result
+
+
 @mcp.tool()
 async def kokoro_install(
     install_dir: Optional[str] = None,
@@ -101,13 +247,58 @@ async def kokoro_install(
                 # Check if the requested version is already installed
                 if is_version_installed(Path(install_dir), version):
                     current_version = get_current_version(Path(install_dir))
+                    
+                    # Determine which start script to use
+                    system = platform.system()
+                    if system == "Darwin":
+                        start_script_name = "start-gpu_mac.sh"
+                    else:
+                        start_script_name = "start-gpu.sh"  # Default to GPU version
+                    
+                    start_script_path = os.path.join(install_dir, start_script_name)
+                    
+                    # If a custom port is requested, create custom start script
+                    if port != 8880 and os.path.exists(start_script_path):
+                        logger.info(f"Creating custom start script for port {port}")
+                        with open(start_script_path, 'r') as f:
+                            script_content = f.read()
+                        modified_script = script_content.replace("--port 8880", f"--port {port}")
+                        custom_script_name = f"start-custom-{port}.sh"
+                        custom_script_path = os.path.join(install_dir, custom_script_name)
+                        with open(custom_script_path, 'w') as f:
+                            f.write(modified_script)
+                        os.chmod(custom_script_path, 0o755)
+                        start_script_path = custom_script_path
+                    
+                    # Always update service files even if kokoro is already installed
+                    logger.info("Kokoro is already installed, updating service files...")
+                    service_update_result = await update_kokoro_service_files(
+                        install_dir=install_dir,
+                        voicemode_dir=voicemode_dir,
+                        port=port,
+                        start_script_path=start_script_path,
+                        auto_enable=auto_enable
+                    )
+                    
+                    # Build response message
+                    message = f"kokoro-fastapi version {current_version} already installed."
+                    if service_update_result.get("updated"):
+                        message += " Service files updated."
+                    if service_update_result.get("enabled"):
+                        message += " Service auto-enabled."
+                    
                     return {
                         "success": True,
                         "install_path": install_dir,
                         "models_path": models_dir,
                         "already_installed": True,
+                        "service_files_updated": service_update_result.get("updated", False),
                         "version": current_version,
-                        "message": f"kokoro-fastapi version {current_version} already installed. Use force_reinstall=True to reinstall."
+                        "plist_path": service_update_result.get("plist_path"),
+                        "service_path": service_update_result.get("service_path"),
+                        "start_script": start_script_path,
+                        "service_url": f"http://127.0.0.1:{port}",
+                        "message": message
                     }
         
         # Check Python version
@@ -215,7 +406,21 @@ async def kokoro_install(
             "message": f"Kokoro-fastapi {current_version} installed. Run: cd {install_dir} && ./{os.path.basename(start_script_path)}{' (' + migration_msg + ')' if migration_msg else ''}"
         }
         
-        # Install launchagent on macOS
+        # Install/update service files
+        service_update_result = await update_kokoro_service_files(
+            install_dir=install_dir,
+            voicemode_dir=voicemode_dir,
+            port=port,
+            start_script_path=start_script_path,
+            auto_enable=auto_enable
+        )
+        
+        if not service_update_result.get("success"):
+            logger.error(f"Failed to update service files: {service_update_result.get('error', 'Unknown error')}")
+            result["error"] = f"Service file update failed: {service_update_result.get('error', 'Unknown error')}"
+            return result
+        
+        # Update result with service file information based on platform
         if system == "Darwin":
             logger.info("Installing launchagent for automatic startup...")
             launchagents_dir = os.path.expanduser("~/Library/LaunchAgents")
